﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class CutsceneManager : MonoBehaviour {
	//a list of all the cutscenes the cutscene manager will play through.
	//these cutscenes are created in editor
	[SerializeField]
	List<Cutscene> cutscenes;
	//A link to the movement event script that is attached to the cutscene manager
	[SerializeField]
	MovementEvent movementEvent;
	//A link to the dialogue event script that is attached to the cutscene manager
	[SerializeField]
	DialogueEvent dialogueEvent;
    //A link to the camera event script that is attached to the cutscene manager
    [SerializeField]
    CameraEvent cameraEvent;
    //temporary bool to check if a cutscene is playing or not
    bool isPlaying = false;
	public void startCutscene(int cutsceneNumber) {
        isPlaying = true;
		//if the function tries to play a cutscene we dont have throw an error
		if (cutsceneNumber >= cutscenes.Count) {
			Debug.LogError ("tried to play a cutscene with a cutscene number greater than " +
			"the number of cutscenes assigned to the cutscene manager.");
			return;
		}
		//starts to play the cutscene
		StartCoroutine(playCutscene (cutscenes [cutsceneNumber]));
	}

	public IEnumerator playCutscene(Cutscene cutscene) {
		//goes through all the cutscene actions within the selected cutscene, playing them all
		for (int i = 0; i < cutscene.cutsceneActions.Count; i++) {
			//checks on what type of cutscene event this is.
			if (cutscene.cutsceneActions [i].thisEventType == eventType.characterMovement) {
				//starts a new coroutine of the cutscene action playing and pauses this coroutine in the process
				yield return StartCoroutine (movementEvent.movementAction (cutscene.cutsceneActions [i]));
			} else if (cutscene.cutsceneActions [i].thisEventType == eventType.cameraMovement) {
				//starts a new coroutine of the cutscene action playing and pauses this coroutine in the process
				yield return StartCoroutine (cameraEvent.cameraAction (cutscene.cutsceneActions [i]));
			} else if (cutscene.cutsceneActions [i].thisEventType == eventType.dialogue) {
				//starts a new coroutine of the cutscene action playing and pauses this coroutine in the process
				yield return StartCoroutine (dialogueEvent.dialogueAction (cutscene.cutsceneActions [i]));
			}
		}
		//this function is called when there are no more actions left for the cutscene to do
		stopCutscene ();
	}
	// allow player to skip certain events (dialogue, jump to start of next event)

	public void stopCutscene() {
        isPlaying = false;
		//resets the camera position and zoom
		Camera.main.transform.position = new Vector3(3.75f, 7.7f, -1.16f);
        Camera.main.orthographicSize = 4.143829f;
	}
    //temp update function to check for spacebar input
    void Update()
    {
        if (Input.GetKey(KeyCode.Space) && isPlaying == false)
        {
            startCutscene(0);
        }
    }
}

//declaration of what a cutscene is. It is simply a list of cutscene events
//this being a struct allows for each cutscene to be edited in the unity editor
[System.Serializable]
public struct Cutscene {
	[SerializeField]
	public List<CutsceneEvent> cutsceneActions;
}